#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-1bmnPxqV0QM4wVBTzlF1Gm
key:                  uri-bytestring-aeson-0.1.0.9-1bmnPxqV0QM4wVBTzlF1Gm
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  52eaa0a2eb4bc5fe2c528c27422616e8
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-1bmnPxqV0QM4wVBTzlF1Gm
depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2
    uri-bytestring-0.3.3.1-8SfJi4NBb2ETgt0TdQqjs

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

